@@ -1,4 +1,3 @@
-from plain.admin.toolbar import ToolbarPanel, register_toolbar_panel
 from plain.admin.views import (
     AdminModelDetailView,
     AdminModelListView,
@@ -9,19 +8,14 @@ from plain.admin.views import (
 from .models import Session
 
 
-@register_toolbar_panel
-class SessionToolbarPanel(ToolbarPanel):
-    name = "Session"
-    template_name = "toolbar/session.html"
-
-
 @register_viewset
 class SessionAdmin(AdminViewset):
     class ListView(AdminModelListView):
         model = Session
-        fields = ["session_key", "expires_at", "created_at"]
+        fields = ["id", "expires_at", "created_at"]
         search_fields = ["session_key"]
         nav_section = "Sessions"
+        nav_icon = "person-badge"
         queryset_order = ["-created_at"]
 
     class DetailView(AdminModelDetailView):
