@@ -1,11 +1,12 @@
+from plain.sessions.views import SessionViewMixin
 from plain.urls import Router, path
 from plain.views import View
 
 
-class IndexView(View):
+class IndexView(SessionViewMixin, View):
     def get(self):
         # Store something so the session is saved
-        self.request.session["foo"] = "bar"
+        self.session["foo"] = "bar"
         return "test"
 
 
